<?PHP
/**
 * Test for ensuring that search RSS feeds are generated correctly.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

use PHPUnit\Framework\TestCase;


/**
 * Tests for the manifest.
 */
abstract class MD_STD_RSS_TEST extends TestCase {

    protected string $feed;

    /**
     * Protected function testRssFeedValidity.
     *
     * @return void
     */
    final public function testRssFeedValidity() {

        $domDoc = new DomDocument();
        self::assertTrue($domDoc->loadXML($this->feed));
        self::assertTrue($domDoc->schemaValidate(__DIR__ . "/../../assets/xsd/Rss2.xsd"));
        unset($domDoc);

    }

    /**
     * Checks for the availability of RSS feed links and encosures.
     *
     * @return void
     */
    final public function testRssFeedLinksAndEnclosure() {

        if (!($xmlData = simplexml_load_string($this->feed))) {
            throw new Exception("Failed to load RSS feed string to SimpleXML element");
        }

        self::assertNotEmpty((string)$xmlData->channel->title);
        self::assertTrue(MD_STD::checkUrlIsReachable((string)$xmlData->channel->image->url), "Path " . $xmlData->channel->image->url . " does not appear to be a reachable URL");
        self::assertTrue(MD_STD::checkUrlIsReachable((string)$xmlData->channel->image->link), "Path " . $xmlData->channel->image->link . " does not appear to be a reachable URL");

        self::assertTrue(MD_STD::checkUrlIsReachable((string)$xmlData->channel->item->link), "Path " . $xmlData->channel->item->link . " does not appear to be a reachable URL");

        if (($firstEntryImg = $xmlData->channel->item->enclosure) === null) {
            throw new Exception("First item does not seem to have an enclosure");
        }
        if (($firstEntryImgAttr = $firstEntryImg->attributes()) === null) {
            throw new Exception("First enclosure does not seem to have attributes");
        }

        self::assertTrue(MD_STD::checkUrlIsReachable((string)$firstEntryImgAttr->url), "First enclosure does not appear to be a reachable URL (" . $firstEntryImgAttr->url . ")");

    }
}
